---
title: '[공지]신한카드 통합앱 패키지 이름 추가 안내'
category: 공지사항
seo:
  title: 신한카드 통합앱 패키지 이름 추가 안내
  description: 포트원 고객지원팀이 제공하는 신한카드 통합앱 패키지 이름 추가 안내입니다. 관련 가이드를 통해 상세정보를 확인하세요.
  keywords: null
tags:
  - 공지사항
datetime: 2024-01-25T15:00:00.000Z
---

안녕하세요, 포트원 고객지원팀입니다.

신한카드 그룹 통합앱인 “신한 통합SOL”이 출시됨에 따라 앱 패키지명을 추가해주셔야 함을 안내드립니다.

안드로이드로 연동하시는 경우 '[해당 가이드 ↗](https://guide.portone.io/28c179a7-1dae-475e-8e23-84b8c427be19#28c179a7-1dae-475e-8e23-84b8c427be19)'를 참고하시어 앱패키지명에 AndroidManifest.xml에 신한슈퍼솔 앱을 추가하여주시기 바랍니다.

<Callout content="신한카드 그룹 통합앱인 &quot;신한 슈퍼SOL&quot;이 12/18(월) 출시되어 안내드립니다.

가맹점이 운영중인 앱에서 신한카드를 선택하여 결제하면

- 신한 SOL Pay (구 신한플레이)
- 신한 Super SOL
두 가지 결제 가능한 앱을 확인할 수 있습니다.
&quot;신한 Super SOL&quot;이 신규 출시되었으며, 결제 시 해당 앱이 정상 호출되지 않는 경우 패키지 이름 등록 조치를 취하시면 됩니다.

○ 대상상점: 가맹점 앱에서 &quot;신한 슈퍼SOL&quot; 앱이 정상 호출되지 않는 상점

○ 적용요청일자: 2023 년 12월 18일 부터 ~

○ 요청사항: &quot;신한 슈퍼SOL&quot; 앱 패키지이름 적용 요청

○ Android 앱 패키지 : com.shinhan.smartcaremgr
*Android 앱에 한하여 적용하며, 운영중인 앱이 Google로부터 Query all package 권한 획득한 앱은 해당사항 없음
*iOS는 해당사항 없음" />

감사합니다.
